jenkins-bot has submitted this change and it was merged. ( 
https://gerrit.wikimedia.org/r/413726 )

Change subject: [IMPR][bugfix] Add missing wikimediachapter codes
......................................................................

[IMPR][bugfix] Add missing wikimediachapter codes

Updated from https://meta.wikimedia.org/wiki/Special:SiteMatrix

+ sort closed and removed sites on WM projects alphabetically

Bug: T103288
Change-Id: Id6772363cb3e971f11f8172b87007008888c1d07
---
M pywikibot/families/wikibooks_family.py
M pywikibot/families/wikimediachapter_family.py
M pywikibot/families/wikiquote_family.py
M pywikibot/families/wiktionary_family.py
4 files changed, 14 insertions(+), 11 deletions(-)

Approvals:
  Xqt: Looks good to me, approved
  jenkins-bot: Verified



diff --git a/pywikibot/families/wikibooks_family.py 
b/pywikibot/families/wikibooks_family.py
index 1593fed..3142d76 100644
--- a/pywikibot/families/wikibooks_family.py
+++ b/pywikibot/families/wikibooks_family.py
@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """Family module for Wikibooks."""
 #
-# (C) Pywikibot team, 2005-2017
+# (C) Pywikibot team, 2005-2018
 #
 # Distributed under the terms of the MIT license.
 #
@@ -20,8 +20,8 @@
     closed_wikis = [
         # See https://noc.wikimedia.org/conf/highlight.php?file=closed.dblist
         'aa', 'ak', 'als', 'ang', 'as', 'ast', 'ay',
-        'bi', 'bm', 'bo', 'ch', 'co', 'ga', 'got', 'gn',
-        'gu', 'kn', 'ie', 'ks', 'lb', 'ln', 'lv', 'mi',
+        'bi', 'bm', 'bo', 'ch', 'co', 'ga', 'gn', 'got',
+        'gu', 'ie', 'kn', 'ks', 'lb', 'ln', 'lv', 'mi',
         'mn', 'my', 'na', 'nah', 'nds', 'ps', 'qu', 'rm',
         'se', 'simple', 'su', 'sw', 'tk', 'ug', 'uz',
         'vo', 'wa', 'xh', 'yo', 'za', 'zh-min-nan', 'zu',
diff --git a/pywikibot/families/wikiquote_family.py 
b/pywikibot/families/wikiquote_family.py
index 8110e58..d1fcbf5 100644
--- a/pywikibot/families/wikiquote_family.py
+++ b/pywikibot/families/wikiquote_family.py
@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """Family module for Wikiquote."""
 #
-# (C) Pywikibot team, 2005-2017
+# (C) Pywikibot team, 2005-2018
 #
 # Distributed under the terms of the MIT license.
 #
@@ -21,7 +21,7 @@
         # See https://noc.wikimedia.org/conf/highlight.php?file=closed.dblist
         'als', 'am', 'ang', 'ast', 'bm', 'co', 'cr', 'ga', 'kk',
         'kr', 'ks', 'kw', 'lb', 'na', 'nds', 'qu', 'simple',
-        'tk', 'tt', 'ug', 'vo', 'za', 'zh_min_nan',
+        'tk', 'tt', 'ug', 'vo', 'za', 'zh-min-nan',
     ]

     removed_wikis = [
diff --git a/pywikibot/families/wiktionary_family.py 
b/pywikibot/families/wiktionary_family.py
index 326231d..64e3393 100644
--- a/pywikibot/families/wiktionary_family.py
+++ b/pywikibot/families/wiktionary_family.py
@@ -26,7 +26,7 @@

     removed_wikis = [
         # See https://noc.wikimedia.org/conf/highlight.php?file=deleted.dblist
-        'dk', 'ba', 'tlh', 'tokipona',
+        'ba', 'dk', 'tlh', 'tokipona',
     ]

     def __init__(self):

diff --git a/pywikibot/families/wikimediachapter_family.py 
b/pywikibot/families/wikimediachapter_family.py
index bb007eb..4181d3c 100644
--- a/pywikibot/families/wikimediachapter_family.py
+++ b/pywikibot/families/wikimediachapter_family.py
@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-"""Family module for Wikimedia chapter wikis."""
+"""Family module for Wikimedia chapter, thematic organisation and WUG wikis."""
 #
-# (C) Pywikibot team, 2012-2015
+# (C) Pywikibot team, 2012-2018
 #
 # Distributed under the terms of the MIT license.
 #
@@ -13,14 +13,17 @@

 class Family(family.SubdomainFamily, family.WikimediaFamily):

     """Family for Wikimedia chapters hosted on wikimedia.org."""

     name = 'wikimediachapter'
     code_aliases = {}

+    closed_wikis = ['nz', 'pa-us', ]
+
     codes = [
-        'ar', 'br', 'bd', 'co', 'dk', 'fi', 'mk', 'mx', 'nl', 'no',
-        'nyc', 'pl', 'rs', 'ru', 'se', 'ua', 'uk', 've',
+        'am', 'ar', 'bd', 'be', 'br', 'ca', 'cn', 'co', 'dk', 'ec', 'et', 'fi',
+        'il', 'mai', 'mk', 'mx', 'nl', 'no', 'nyc', 'pl', 'pt', 'rs', 'ru',
+        'se', 'tr', 'ua', 'uk', 've', 'wb',
     ]

     @property
@@ -13,14 +13,17 @@
 class Family(family.SubdomainFamily, family.WikimediaFamily):

-    """Family for Wikimedia chapters hosted on wikimedia.org."""
+    """Family class for WCH, WTO and WUG wikis hosted on wikimedia.org."""

     name = 'wikimediachapter'
--
To view, visit https://gerrit.wikimedia.org/r/413726
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-Project: pywikibot/core
Gerrit-Branch: master
Gerrit-MessageType: merged
Gerrit-Change-Id: Id6772363cb3e971f11f8172b87007008888c1d07
Gerrit-Change-Number: 413726
Gerrit-PatchSet: 8
Gerrit-Owner: Dvorapa <dvor...@seznam.cz>
Gerrit-Reviewer: Dvorapa <dvor...@seznam.cz>
Gerrit-Reviewer: Dzahn <dz...@wikimedia.org>
Gerrit-Reviewer: John Vandenberg <jay...@gmail.com>
Gerrit-Reviewer: Liuxinyu970226 <541329...@qq.com>
Gerrit-Reviewer: Nemo bis <federicol...@tiscali.it>
Gerrit-Reviewer: Ricordisamoa <ricordisa...@openmailbox.org>
Gerrit-Reviewer: XZise <commodorefabia...@gmx.de>
Gerrit-Reviewer: Xqt <i...@gno.de>
Gerrit-Reviewer: Zhuyifei1999 <zhuyifei1...@gmail.com>
Gerrit-Reviewer: Zoranzoki21 <zorandori4...@gmail.com>
Gerrit-Reviewer: jenkins-bot <>
_______________________________________________
Pywikibot-commits mailing list
Pywikibot-commits@lists.wikimedia.org
https://lists.wikimedia.org/mailman/listinfo/pywikibot-commits

Reply via email to